@@ -35,8 +35,8 @@ class ConsumerClient:
             self.talosHttpClient.set_query_string("type=renew")
             iprot = TCompactProtocol(self.talosHttpClient)
             return ConsumerService.Client(iprot).renew(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.consumerClientLock.release()
 
@@ -46,8 +46,8 @@ class ConsumerClient:
             self.talosHttpClient.set_query_string("type=lockWorker")
             iprot = TCompactProtocol(self.talosHttpClient)
             return ConsumerService.Client(iprot).lockWorker(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.consumerClientLock.release()
 
@@ -57,8 +57,8 @@ class ConsumerClient:
             self.talosHttpClient.set_query_string("type=queryWorker")
             iprot = TCompactProtocol(self.talosHttpClient)
             return ConsumerService.Client(iprot).queryWorker(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.consumerClientLock.release()
 
@@ -68,8 +68,8 @@ class ConsumerClient:
             self.talosHttpClient.set_query_string("type=lockPartition")
             iprot = TCompactProtocol(self.talosHttpClient)
             return ConsumerService.Client(iprot).lockPartition(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.consumerClientLock.release()
 
@@ -79,8 +79,8 @@ class ConsumerClient:
             self.talosHttpClient.set_query_string("type=unlockPartition")
             iprot = TCompactProtocol(self.talosHttpClient)
             return ConsumerService.Client(iprot).unlockPartition(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.consumerClientLock.release()
 
@@ -90,8 +90,8 @@ class ConsumerClient:
             self.talosHttpClient.set_query_string("type=queryOffset")
             iprot = TCompactProtocol(self.talosHttpClient)
             return ConsumerService.Client(iprot).queryOffset(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.consumerClientLock.release()
 
@@ -101,8 +101,8 @@ class ConsumerClient:
             self.talosHttpClient.set_query_string("type=updateOffset")
             iprot = TCompactProtocol(self.talosHttpClient)
             return ConsumerService.Client(iprot).updateOffset(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.consumerClientLock.release()
 
@@ -112,8 +112,8 @@ class ConsumerClient:
             self.talosHttpClient.set_query_string("type=getWorkerId")
             iprot = TCompactProtocol(self.talosHttpClient)
             return ConsumerService.Client(iprot).getWorkerId(request).workerId
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.consumerClientLock.release()
 
@@ -131,8 +131,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=createTopic")
             iprot = TCompactProtocol(self.talosHttpClient)
             return TopicService.Client(iprot).createTopic(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -142,8 +142,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=getDescribeInfo")
             iprot = TCompactProtocol(self.talosHttpClient)
             return TopicService.Client(iprot).getDescribeInfo(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -153,8 +153,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=getTopicAttribute")
             iprot = TCompactProtocol(self.talosHttpClient)
             return TopicService.Client(iprot).getTopicAttribute(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -164,8 +164,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=deleteTopic")
             iprot = TCompactProtocol(self.talosHttpClient)
             return TopicService.Client(iprot).deleteTopic(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -175,8 +175,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=changeTopicAttribute")
             iprot = TCompactProtocol(self.talosHttpClient)
             return TopicService.Client(iprot).changeTopicAttribute(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -186,8 +186,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=listTopics")
             iprot = TCompactProtocol(self.talosHttpClient)
             return TopicService.Client(iprot).listTopics().topicInfos
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -198,8 +198,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=setPermission")
             iprot = TCompactProtocol(self.talosHttpClient)
             TopicService.Client(iprot).setPermission(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -209,8 +209,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=revokePermission")
             iprot = TCompactProtocol(self.talosHttpClient)
             TopicService.Client(iprot).setPermission(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -220,8 +220,8 @@ class TopicClient:
             self.talosHttpClient.set_query_string("type=listPermission")
             iprot = TCompactProtocol(self.talosHttpClient)
             return TopicService.Client(iprot).listPermission(request).permissions
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.topicClientLock.release()
 
@@ -239,8 +239,8 @@ class MessageClient:
             self.talosHttpClient.set_query_string("type=getMessage")
             iprot = TCompactProtocol(self.talosHttpClient)
             return MessageService.Client(iprot).getMessage(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.messageClientLock.release()
 
@@ -250,8 +250,8 @@ class MessageClient:
             self.talosHttpClient.set_query_string("type=putMessage")
             iprot = TCompactProtocol(self.talosHttpClient)
             return MessageService.Client(iprot).putMessage(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.messageClientLock.release()
 
@@ -261,8 +261,8 @@ class MessageClient:
             self.talosHttpClient.set_query_string("type=getTopicOffset")
             iprot = TCompactProtocol(self.talosHttpClient)
             return MessageService.Client(iprot).getTopicOffset(request).offsetInfoList
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.messageClientLock.release()
 
@@ -272,8 +272,8 @@ class MessageClient:
             self.talosHttpClient.set_query_string("type=getPartitionOffset")
             iprot = TCompactProtocol(self.talosHttpClient)
             return MessageService.Client(iprot).getPartitionOffset(request).offsetInfo
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.messageClientLock.release()
 
@@ -283,8 +283,8 @@ class MessageClient:
             self.talosHttpClient.set_query_string("type=getScheduleInfo")
             iprot = TCompactProtocol(self.talosHttpClient)
             return MessageService.Client(iprot).getScheduleInfo(request).scheduleInfo
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.messageClientLock.release()
 
@@ -302,8 +302,8 @@ class QuotaClient:
             self.talosHttpClient.set_query_string("type=applyQuota")
             iprot = TCompactProtocol(self.talosHttpClient)
             QuotaService.Client(iprot).applyQuota(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.quotaClientLock.release()
 
@@ -313,8 +313,8 @@ class QuotaClient:
             self.talosHttpClient.set_query_string("type=revokeQuota")
             iprot = TCompactProtocol(self.talosHttpClient)
             return QuotaService.Client(iprot).revokeQuota(request)
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.quotaClientLock.release()
 
@@ -324,8 +324,8 @@ class QuotaClient:
             self.talosHttpClient.set_query_string("type=listQuota")
             iprot = TCompactProtocol(self.talosHttpClient)
             return QuotaService.Client(iprot).listQuota()
-        except:
-            pass
+        except Exception as e:
+            raise e
         finally:
             self.quotaClientLock.release()
 
